import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["className", "value", "selection", "extensions", "onChange", "theme", "height", "minHeight", "maxHeight", "width", "minWidth", "maxWidth"];
import React, { useEffect, useRef, useImperativeHandle } from "react";
import { basicSetup } from "@codemirror/basic-setup";
import { StateEffect } from "@codemirror/state";
import { EditorView } from "@codemirror/view";
import { useCodeMirror } from './useCodeMirror';
import { defaultDarkThemeOption } from './theme/dark';
import { defaultLightThemeOption } from './theme/light';
import { jsx as _jsx } from "react/jsx-runtime";
export * from './useCodeMirror';
export * from "@codemirror/view";
export * from "@codemirror/basic-setup";
export * from "@codemirror/state";
export default /*#__PURE__*/React.forwardRef(function (props, ref) {
  var className = props.className,
      value = props.value,
      selection = props.selection,
      _props$extensions = props.extensions,
      extensions = _props$extensions === void 0 ? [] : _props$extensions,
      onChange = props.onChange,
      _props$theme = props.theme,
      theme = _props$theme === void 0 ? 'light' : _props$theme,
      _props$height = props.height,
      height = _props$height === void 0 ? '' : _props$height,
      _props$minHeight = props.minHeight,
      minHeight = _props$minHeight === void 0 ? '' : _props$minHeight,
      _props$maxHeight = props.maxHeight,
      maxHeight = _props$maxHeight === void 0 ? '' : _props$maxHeight,
      _props$width = props.width,
      width = _props$width === void 0 ? '' : _props$width,
      _props$minWidth = props.minWidth,
      minWidth = _props$minWidth === void 0 ? '' : _props$minWidth,
      _props$maxWidth = props.maxWidth,
      maxWidth = _props$maxWidth === void 0 ? '' : _props$maxWidth,
      other = _objectWithoutPropertiesLoose(props, _excluded);

  var editor = useRef(null);
  var defaultThemeOption = EditorView.theme({
    "&": {
      height: height,
      minHeight: minHeight,
      maxHeight: maxHeight,
      width: width,
      minWidth: minWidth,
      maxWidth: maxWidth
    }
  });
  var getExtensions = [basicSetup, defaultThemeOption];
  theme === 'light' ? getExtensions.push(defaultLightThemeOption) : getExtensions.push(defaultDarkThemeOption);
  getExtensions = getExtensions.concat(extensions);

  var _useCodeMirror = useCodeMirror({
    container: editor.current,
    value: value,
    selection: selection,
    onChange: onChange,
    extensions: getExtensions
  }),
      state = _useCodeMirror.state,
      view = _useCodeMirror.view,
      container = _useCodeMirror.container,
      setContainer = _useCodeMirror.setContainer;

  useImperativeHandle(ref, function () {
    return {
      editor: container,
      state: state,
      view: view
    };
  });
  useEffect(function () {
    setContainer(editor.current);
    return function () {
      if (view) {
        view.destroy();
      }
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  useEffect(function () {
    if (view) {
      view.dispatch({
        effects: StateEffect.reconfigure.of(getExtensions)
      });
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [theme, extensions, height, height, minHeight, maxHeight, width, minWidth, maxWidth]);
  return /*#__PURE__*/_jsx("div", _extends({
    ref: editor,
    className: "cm-theme-" + theme + " " + (className || '')
  }, other));
});
//# sourceMappingURL=index.js.map